import Vue from "vue";
import Keyboard from "../components/KeyboardDisplay.vue";
import store from "../store";

let keyboard = null;

const createKeyboard = (input) => {
  const keyboardDiv = document.createElement("div");
  input.parentElement.appendChild(keyboardDiv);
  keyboard = new Vue({
    store,
    render: (h) => {
      return h(Keyboard, {
        props: {
          inputField: input,
          optionsModal: false,
        },
      });
    },
    el: keyboardDiv,
  });
  keyboard._inputField = input;
};

const rmKeyboard = (k) => {
  k.$destroy();
  k.$el.parentElement.removeChild(k.$el);
  keyboard = null;
};

// Open the keyboard on inputs and text areas
const inputFields = [
  ...document.getElementsByTagName("input"),
  ...document.getElementsByTagName("textarea"),
];
for (const input of inputFields) {
  // Handle the case where the input is already focused when this script is loaded
  if (!keyboard && document.activeElement === input) createKeyboard(input);

  // Open the keyboard when focusing a new input
  input.onfocus = () => {
    if (keyboard && input !== keyboard._inputField) rmKeyboard(keyboard);
    if (!keyboard) createKeyboard(input);
  };

  // Keep the focus on the input while typing on the keyboard
  input.onblur = (e) => {
    if (!keyboard) return;
    // We need a short delay before checking where the user moved the focus
    setTimeout(() => {
      if (keyboard.$el.contains(document.activeElement))
        keyboard._inputField.focus();
      // Handle focusing a new input field; remove keyboard otherwise
      else if (
        keyboard._inputField !== document.activeElement ||
        keyboard._inputField === e.target
      )
        rmKeyboard(keyboard);
    }, 1);
  };
}
